pub struct ChatCompletionObjectMessage {
pub content: Option<String>,
pub tool_calls: Vec<ToolCall>,
pub role: ChatCompletionRole,
pub function_call: Option<ChatMessageFunctionCall>,
}Expand description
Represents a chat completion message generated by the model.
Fields
content: Option<String>The contents of the message.
tool_calls: Vec<ToolCall>The tool calls generated by the model, such as function calls.
role: ChatCompletionRoleThe role of the author of this message.
function_call: Option<ChatMessageFunctionCall>Deprecated. The name and arguments of a function that should be called, as generated by the model.