pub struct ChatCompletionRequestFunctionParameters {
pub schema_type: JSONSchemaType,
pub properties: Option<HashMap<String, Box<JSONSchemaDefine>>>,
pub required: Option<Vec<String>>,
}Expand description
The parameters the functions accepts, described as a JSON Schema object. See the guide for examples, and the JSON Schema reference for documentation about the format.
To describe a function that accepts no parameters, provide the value {"type": "object", "properties": {}}.
Fields
schema_type: JSONSchemaTypeproperties: Option<HashMap<String, Box<JSONSchemaDefine>>>required: Option<Vec<String>>Trait Implementations
sourceimpl Clone for ChatCompletionRequestFunctionParameters
impl Clone for ChatCompletionRequestFunctionParameters
sourcefn clone(&self) -> ChatCompletionRequestFunctionParameters
fn clone(&self) -> ChatCompletionRequestFunctionParameters
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl<'de> Deserialize<'de> for ChatCompletionRequestFunctionParameters
impl<'de> Deserialize<'de> for ChatCompletionRequestFunctionParameters
sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more