pub struct ToolFunctionParameters {
pub schema_type: JSONSchemaType,
pub properties: Option<IndexMap<String, Box<JSONSchemaDefine>>>,
pub required: Option<Vec<String>>,
}Expand description
The parameters the functions accepts, described as a JSON Schema object.
See the guide for examples, and the JSON Schema reference for documentation about the format.
To describe a function that accepts no parameters, provide the value
{"type": "object", "properties": {}}.
Fields
schema_type: JSONSchemaTypeproperties: Option<IndexMap<String, Box<JSONSchemaDefine>>>required: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for ToolFunctionParameters
impl Clone for ToolFunctionParameters
Sourcefn clone(&self) -> ToolFunctionParameters
fn clone(&self) -> ToolFunctionParameters
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ToolFunctionParameters
impl Debug for ToolFunctionParameters
Sourceimpl<'de> Deserialize<'de> for ToolFunctionParameters
impl<'de> Deserialize<'de> for ToolFunctionParameters
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more