Enum endpoints::common::FinishReason
source · pub enum FinishReason {
stop,
length,
function_call,
}Expand description
The reason the model stopped generating tokens.
Variants
stop
stop if the model hit a natural stop point or a provided stop sequence.
length
length if the maximum number of tokens specified in the request was reached.
function_call
function_call if the model called a function.