pub struct CompletionRequest {Show 16 fields
pub model: Option<String>,
pub prompt: CompletionPrompt,
pub best_of: Option<u32>,
pub echo: Option<bool>,
pub frequency_penalty: Option<f32>,
pub logit_bias: Option<HashMap<String, f32>>,
pub logprobs: Option<u32>,
pub max_tokens: Option<u32>,
pub n: Option<u32>,
pub presence_penalty: Option<f32>,
pub stop: Option<Vec<String>>,
pub stream: Option<bool>,
pub suffix: Option<String>,
pub temperature: Option<f32>,
pub top_p: Option<f32>,
pub user: Option<String>,
}Expand description
Creates a completion for the provided prompt and parameters.
Fields
model: Option<String>ID of the model to use.
prompt: CompletionPromptThe prompt(s) to generate completions for, encoded as a string, array of strings, array of tokens, or array of token arrays.
best_of: Option<u32>Generates best_of completions server-side and returns the “best” (the one with the highest log probability per token). Results cannot be streamed.When used with n_choice, best_of controls the number of candidate completions and n_choice specifies how many to return – best_of must be greater than n_choice.
Defaults to 1.
echo: Option<bool>Echo back the prompt in addition to the completion. Defaults to false.
frequency_penalty: Option<f32>Number between -2.0 and 2.0. Positive values penalize new tokens based on their existing frequency in the text so far, decreasing the model’s likelihood to repeat the same line verbatim. Defaults to 0.0.
logit_bias: Option<HashMap<String, f32>>Modify the likelihood of specified tokens appearing in the completion. Accepts a json object that maps tokens (specified by their token ID in the GPT tokenizer) to an associated bias value from -100 to 100. You can use this tokenizer tool (which works for both GPT-2 and GPT-3) to convert text to token IDs. Mathematically, the bias is added to the logits generated by the model prior to sampling. The exact effect will vary per model, but values between -1 and 1 should decrease or increase likelihood of selection; values like -100 or 100 should result in a ban or exclusive selection of the relevant token. As an example, you can pass {“50256”: -100} to prevent the <|endoftext|> token from being generated. Defaults to None.
logprobs: Option<u32>Include the log probabilities on the logprobs most likely tokens, as well the chosen tokens. For example, if logprobs is 5, the API will return a list of the 5 most likely tokens. The API will always return the logprob of the sampled token, so there may be up to logprobs+1 elements in the response.
The maximum value for logprobs is 5. Defaults to None.
max_tokens: Option<u32>The maximum number of tokens to generate in the completion.
The token count of your prompt plus max_tokens cannot exceed the model’s context length. Defaults to 16.
n: Option<u32>How many completions to generate for each prompt. Defaults to 1.
presence_penalty: Option<f32>Number between -2.0 and 2.0. Positive values penalize new tokens based on whether they appear in the text so far, increasing the model’s likelihood to talk about new topics. Defaults to 0.0.
stop: Option<Vec<String>>Up to 4 sequences where the API will stop generating further tokens. The returned text will not contain the stop sequence. Defaults to None.
stream: Option<bool>Whether to stream the results as they are generated. Useful for chatbots. Defaults to false.
suffix: Option<String>The suffix that comes after a completion of inserted text. Defaults to None.
temperature: Option<f32>Adjust the randomness of the generated text. Between 0.0 and 2.0. Higher values like 0.8 will make the output more random, while lower values like 0.2 will make it more focused and deterministic.
We generally recommend altering this or top_p but not both. Defaults to 1.0.
top_p: Option<f32>Limit the next token selection to a subset of tokens with a cumulative probability above a threshold P. The value should be between 0.0 and 1.0.
Top-p sampling, also known as nucleus sampling, is another text generation method that selects the next token from a subset of tokens that together have a cumulative probability of at least p. This method provides a balance between diversity and quality by considering both the probabilities of tokens and the number of tokens to sample from. A higher value for top_p (e.g., 0.95) will lead to more diverse text, while a lower value (e.g., 0.5) will generate more focused and conservative text. Defaults to 1.0.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.